| Title: | Sparse Generative Model and Its EM Algorithm |
|---|---|
| Description: | Implements a generative model that uses a spike-and-slab like prior distribution obtained by multiplying a deterministic binary vector. Such a model allows an EM algorithm, optimizing a type-II log-likelihood. |
| Authors: | Charles Bouveyron, Julien Chiquet, Pierre Latouche, Pierre-Alexandre Mattei |
| Maintainer: | Julien Chiquet <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.1-0 |
| Built: | 2026-05-26 09:58:46 UTC |
| Source: | https://github.com/cran/spinyReg |
Computethe path of solution of a spinyReg fit.
spinyreg(X, Y, alpha = 0.1, gamma = 1, z = rep(1, ncol(X)), intercept = TRUE, normalize = TRUE, verbose = 1, recovery = TRUE, maxit = 1000, eps = 1e-10)spinyreg(X, Y, alpha = 0.1, gamma = 1, z = rep(1, ncol(X)), intercept = TRUE, normalize = TRUE, verbose = 1, recovery = TRUE, maxit = 1000, eps = 1e-10)
X |
matrix of features. Do NOT include intercept. |
Y |
matrix of responses. |
alpha |
numeric scalar; prior value for the alpha parameter (see the model's details). Default is 0.1. |
gamma |
numeric scalar; prior value for the gamma parameter (see the model's details). Default is 1. |
z |
numeric vector; prior support of active variable. Default
is |
intercept |
logical; indicates if a vector of intercepts
should be included in the model. Default is |
normalize |
logical; indicates if predictor variables should
be normalized to have unit L2 norm before fitting. Default is
|
verbose |
integer; activate verbose mode from '0' (nothing) to '2' (detailed output). should be included in the model. Default is |
recovery |
logical; indicates if the full path of models
should be inspected for model selection. Default is |
maxit |
integer; the maximal number of iteration (i.e. number of alternated optimization between each parameter) in the Expectation/Maximization algorithm. |
eps |
a threshold for convergence. Default is |
an object with class spinyreg, see the
documentation page spinyreg for details.
See also spinyreg.
## Not run: data <- read.table(file="http://statweb.stanford.edu/~tibs/ElemStatLearn/datasets/prostate.data") x <- data[, 1:8] y <- data[, 9] out <- spinyreg(x,y,verbose=2) ## End(Not run)## Not run: data <- read.table(file="http://statweb.stanford.edu/~tibs/ElemStatLearn/datasets/prostate.data") x <- data[, 1:8] y <- data[, 9] out <- spinyreg(x,y,verbose=2) ## End(Not run)
Class of object returned by the spinyreg function.
coefficients:numeric vector of coefficients with respect to the original input. Contains the intercept if the model owns any.
alpha:numeric scalar.
gamma:numeric scalar.
normx:Vector (class "numeric") containing the
square root of the sum of squares of each column of the design
matrix.
residuals:Vector of residuals.
r.squared:scalar giving the coefficient of determination.
fitted:Vector of fitted values.
monitoring:List (class "list") which
contains various indicators dealing with the optimization
process.
intercept:Logical which indicates if a intercept is included in the model.
This class comes with the usual predict(object, newx, ...),
fitted(object, ...), residuals(object, ...), coefficients(object, ...),
print(object, ...) and show(object) generic (undocumented) methods.